@@ -502,7 +502,7 @@ class Update(object):
         )
 
         # update firestore in the github app projects
-        print(g.firestore(firestore_project).update_collection(
+        print(g.firestore(firestore_project).update_collection_batch(
             'team_syncs',
             firestore_syncs,
             delete_docs=True,
